import React, { PureComponent } from 'react';
import moment from 'moment';
import { Table, Badge } from 'antd';
import { orderStatuses, Codes } from '../../../utils/config';
import { provCodeToName } from '../../../utils/city';

export default class TableList extends PureComponent {
  handleItemView = (record) => {
    const { onViewItem } = this.props;
    onViewItem(record);
  }

  render() {
    const { dataSource, pagination, ...tableProps } = this.props;

    const columns = [{
      title: '订单编号',
      dataIndex: 'id',
      key: 'id',
      width: '28%',
    }, {
      title: '校区',
      dataIndex: 'campusName',
      key: 'campusName',
      render: (text, record) => (
        <span>{`${provCodeToName(record.provinceCode)}-${record.cityName}-${record.zoneName}`}</span>
      ),
      width: '39%',
    }, {
      title: '状态',
      dataIndex: 'orderStatus',
      key: 'orderStatus',
      render: (text, record) => {
        const statusMap = {
          [Codes.CODE_FORSEND]: 'default',
          [Codes.CODE_COMPLETE]: 'success',
          [Codes.CODE_CANCEL]: 'error',
        };
        return (<Badge status={statusMap[record.orderStatus] || 'processing'} text={orderStatuses[record.orderStatus]} />);
      },
      width: '8%',
    }, {
      title: '下单时间',
      dataIndex: 'gmtCreated',
      key: 'gmtCreated',
      render: text => (
        <div>{moment(text).format('YYYY-MM-DD HH:mm:ss')}</div>
      ),
      width: '17%',
    }, {
      title: '操作',
      dataIndex: 'operation',
      key: 'operation',
      render: (_, record) => <a onClick={() => this.handleItemView(record)}>查看详情</a>,
      width: '8%',
    }];

    // 配置分页
    tableProps.pagination = !!pagination && { ...pagination, showSizeChanger: true, showQuickJumper: true, showTotal: total => `共 ${total} 条` };

    return (
      <Table
        simple
        bordered
        dataSource={dataSource}
        columns={columns}
        rowKey={record => record.id}
        {...tableProps}
      />
    );
  }
}
